@@ -22,7 +22,7 @@
 
 # ----------------------------------------------------------------------------
 
-__version__ = '1.88.1126'
+__version__ = '1.88.1128'
 
 # ----------------------------------------------------------------------------
 
@@ -110,6 +110,7 @@ from ccxt.btctradeua import btctradeua                      # noqa: F401
 from ccxt.btcturk import btcturk                            # noqa: F401
 from ccxt.buda import buda                                  # noqa: F401
 from ccxt.bxinth import bxinth                              # noqa: F401
+from ccxt.bybit import bybit                                # noqa: F401
 from ccxt.ccex import ccex                                  # noqa: F401
 from ccxt.cex import cex                                    # noqa: F401
 from ccxt.chbtc import chbtc                                # noqa: F401
@@ -148,6 +149,7 @@ from ccxt.fcoin import fcoin                                # noqa: F401
 from ccxt.fcoinjp import fcoinjp                            # noqa: F401
 from ccxt.flowbtc import flowbtc                            # noqa: F401
 from ccxt.foxbit import foxbit                              # noqa: F401
+from ccxt.ftx import ftx                                    # noqa: F401
 from ccxt.fybse import fybse                                # noqa: F401
 from ccxt.fybsg import fybsg                                # noqa: F401
 from ccxt.gatecoin import gatecoin                          # noqa: F401
@@ -185,6 +187,7 @@ from ccxt.mixcoins import mixcoins                          # noqa: F401
 from ccxt.negociecoins import negociecoins                  # noqa: F401
 from ccxt.nova import nova                                  # noqa: F401
 from ccxt.oceanex import oceanex                            # noqa: F401
+from ccxt.okcoin import okcoin                              # noqa: F401
 from ccxt.okcoincny import okcoincny                        # noqa: F401
 from ccxt.okcoinusd import okcoinusd                        # noqa: F401
 from ccxt.okex import okex                                  # noqa: F401
@@ -265,6 +268,7 @@ exchanges = [
     'btcturk',
     'buda',
     'bxinth',
+    'bybit',
     'ccex',
     'cex',
     'chbtc',
@@ -303,6 +307,7 @@ exchanges = [
     'fcoinjp',
     'flowbtc',
     'foxbit',
+    'ftx'
     'fybse',
     'fybsg',
     'gatecoin',
@@ -340,6 +345,7 @@ exchanges = [
     'negociecoins',
     'nova',
     'oceanex',
+    'okcoin',
     'okcoincny',
     'okcoinusd',
     'okex',
